@@ -32,7 +32,7 @@ from ..event_util import forward_event_with_results, forward_event
 from ..pubsub import PubSubClient
 
 if TYPE_CHECKING:
-    from ..pubsub import PubSubData, PubSubPointRedemption, PubSubBits
+    from ..pubsub import PubSubData, PubSubPointRedemption, PubSubBits, PubSubModerationAction
     from ..irc import Irc
 
 
@@ -196,6 +196,13 @@ class BaseBot:
         :param data: data specific to the bits being sent
         """
 
+    async def on_pubsub_moderation_action(self, raw: 'PubSubData', data: 'PubSubModerationAction'):
+        """
+        triggered when a moderator does a moderation action such as ban/unban/timeout
+        :param raw: the raw pubsub message
+        :param data: data specific to the moderation action taken
+        """
+
     # endregion
 
     def _create_channels(self):
