@@ -140,6 +140,7 @@ class PubSubClient:
         (
                 self._check_for_channel_point_redemption(data)
                 or self._check_for_bits(data)
+                or self._check_for_moderation_action(data)
                 or self._noop()
         )
 
@@ -166,6 +167,16 @@ class PubSubClient:
         forward_event(Event.on_pubsub_bits, data, PubSubBits(data))
         return True
 
+    def _check_for_moderation_action(self, data: 'PubSubData'):
+        from ..event_util import forward_event
+        from .pubsub_moderation_action import PubSubModerationAction
+
+        if not data.is_moderation_action:
+            return False
+
+        forward_event(Event.on_pubsub_moderation_action, data, PubSubModerationAction(data))
+        return True
+
     async def _send_ping_if_needed(self):
         if self.last_ping_time_diff >= self.PING_SEND_INTERVAL:
             await self._send_ping()
